<a id="mypy-boto3-quicksight"></a>

# mypy-boto3-quicksight

[![PyPI - mypy-boto3-quicksight](https://img.shields.io/pypi/v/mypy-boto3-quicksight.svg?color=blue)](https://pypi.org/project/mypy-boto3-quicksight)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-quicksight.svg?color=blue)](https://pypi.org/project/mypy-boto3-quicksight)
[![Docs](https://img.shields.io/readthedocs/boto3-stubs.svg?color=blue)](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_quicksight/)
[![PyPI - Downloads](https://static.pepy.tech/badge/mypy-boto3-quicksight)](https://pepy.tech/project/mypy-boto3-quicksight)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.QuickSight 1.28.16](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/quicksight.html#QuickSight)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.17.1](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-quicksight docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_quicksight/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-quicksight](#mypy-boto3-quicksight)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Type definitions](#type-definitions)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `QuickSight`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `boto3-stubs` for `QuickSight` service.

```bash
# install with boto3 type annotations
python -m pip install 'boto3-stubs[quicksight]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'boto3-stubs-lite[quicksight]'


# standalone installation
python -m pip install mypy-boto3-quicksight
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y mypy-boto3-quicksight
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto3-stubs[quicksight]` in your environment:

```bash
python -m pip install 'boto3-stubs[quicksight]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `boto3-stubs-lite[quicksight]` in your environment:

```bash
python -m pip install 'boto3-stubs-lite[quicksight]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `boto3-stubs` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `boto3-stubs` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[quicksight]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed `boto3-stubs`

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `boto3-stubs[quicksight]` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[quicksight]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto3-stubs[quicksight]` in your environment:

```bash
python -m pip install 'boto3-stubs[quicksight]'`
```

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `boto3-stubs[quicksight]` in your environment:

```bash
python -m pip install 'boto3-stubs[quicksight]'
```

Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`QuickSightClient` provides annotations for `boto3.client("quicksight")`.

```python
from boto3.session import Session

from mypy_boto3_quicksight import QuickSightClient

client: QuickSightClient = Session().client("quicksight")

# now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_quicksight.paginator` module contains type annotations for all
paginators.

```python
from boto3.session import Session

from mypy_boto3_quicksight import QuickSightClient
from mypy_boto3_quicksight.paginator import (
    ListAnalysesPaginator,
    ListAssetBundleExportJobsPaginator,
    ListAssetBundleImportJobsPaginator,
    ListDashboardVersionsPaginator,
    ListDashboardsPaginator,
    ListDataSetsPaginator,
    ListDataSourcesPaginator,
    ListGroupMembershipsPaginator,
    ListGroupsPaginator,
    ListIAMPolicyAssignmentsPaginator,
    ListIAMPolicyAssignmentsForUserPaginator,
    ListIngestionsPaginator,
    ListNamespacesPaginator,
    ListTemplateAliasesPaginator,
    ListTemplateVersionsPaginator,
    ListTemplatesPaginator,
    ListThemeVersionsPaginator,
    ListThemesPaginator,
    ListUserGroupsPaginator,
    ListUsersPaginator,
    SearchAnalysesPaginator,
    SearchDashboardsPaginator,
    SearchDataSetsPaginator,
    SearchDataSourcesPaginator,
    SearchGroupsPaginator,
)

client: QuickSightClient = Session().client("quicksight")

# Explicit type annotations are optional here
# Types should be correctly discovered by mypy and IDEs
list_analyses_paginator: ListAnalysesPaginator = client.get_paginator("list_analyses")
list_asset_bundle_export_jobs_paginator: ListAssetBundleExportJobsPaginator = client.get_paginator(
    "list_asset_bundle_export_jobs"
)
list_asset_bundle_import_jobs_paginator: ListAssetBundleImportJobsPaginator = client.get_paginator(
    "list_asset_bundle_import_jobs"
)
list_dashboard_versions_paginator: ListDashboardVersionsPaginator = client.get_paginator(
    "list_dashboard_versions"
)
list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
list_data_sets_paginator: ListDataSetsPaginator = client.get_paginator("list_data_sets")
list_data_sources_paginator: ListDataSourcesPaginator = client.get_paginator("list_data_sources")
list_group_memberships_paginator: ListGroupMembershipsPaginator = client.get_paginator(
    "list_group_memberships"
)
list_groups_paginator: ListGroupsPaginator = client.get_paginator("list_groups")
list_iam_policy_assignments_paginator: ListIAMPolicyAssignmentsPaginator = client.get_paginator(
    "list_iam_policy_assignments"
)
list_iam_policy_assignments_for_user_paginator: ListIAMPolicyAssignmentsForUserPaginator = (
    client.get_paginator("list_iam_policy_assignments_for_user")
)
list_ingestions_paginator: ListIngestionsPaginator = client.get_paginator("list_ingestions")
list_namespaces_paginator: ListNamespacesPaginator = client.get_paginator("list_namespaces")
list_template_aliases_paginator: ListTemplateAliasesPaginator = client.get_paginator(
    "list_template_aliases"
)
list_template_versions_paginator: ListTemplateVersionsPaginator = client.get_paginator(
    "list_template_versions"
)
list_templates_paginator: ListTemplatesPaginator = client.get_paginator("list_templates")
list_theme_versions_paginator: ListThemeVersionsPaginator = client.get_paginator(
    "list_theme_versions"
)
list_themes_paginator: ListThemesPaginator = client.get_paginator("list_themes")
list_user_groups_paginator: ListUserGroupsPaginator = client.get_paginator("list_user_groups")
list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
search_analyses_paginator: SearchAnalysesPaginator = client.get_paginator("search_analyses")
search_dashboards_paginator: SearchDashboardsPaginator = client.get_paginator("search_dashboards")
search_data_sets_paginator: SearchDataSetsPaginator = client.get_paginator("search_data_sets")
search_data_sources_paginator: SearchDataSourcesPaginator = client.get_paginator(
    "search_data_sources"
)
search_groups_paginator: SearchGroupsPaginator = client.get_paginator("search_groups")
```

<a id="literals"></a>

### Literals

`mypy_boto3_quicksight.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_quicksight.literals import (
    AnalysisErrorTypeType,
    AnalysisFilterAttributeType,
    AnchorOptionType,
    ArcThicknessOptionsType,
    ArcThicknessType,
    AssetBundleExportFormatType,
    AssetBundleExportJobAnalysisPropertyToOverrideType,
    AssetBundleExportJobDashboardPropertyToOverrideType,
    AssetBundleExportJobDataSetPropertyToOverrideType,
    AssetBundleExportJobDataSourcePropertyToOverrideType,
    AssetBundleExportJobRefreshSchedulePropertyToOverrideType,
    AssetBundleExportJobStatusType,
    AssetBundleExportJobThemePropertyToOverrideType,
    AssetBundleExportJobVPCConnectionPropertyToOverrideType,
    AssetBundleImportFailureActionType,
    AssetBundleImportJobStatusType,
    AssignmentStatusType,
    AuthenticationMethodOptionType,
    AuthorSpecifiedAggregationType,
    AxisBindingType,
    BarChartOrientationType,
    BarsArrangementType,
    BaseMapStyleTypeType,
    BoxPlotFillStyleType,
    CategoricalAggregationFunctionType,
    CategoryFilterFunctionType,
    CategoryFilterMatchOperatorType,
    CategoryFilterSelectAllOptionsType,
    CategoryFilterTypeType,
    ColorFillTypeType,
    ColumnDataRoleType,
    ColumnDataTypeType,
    ColumnOrderingTypeType,
    ColumnRoleType,
    ColumnTagNameType,
    ComparisonMethodType,
    ConditionalFormattingIconDisplayOptionType,
    ConditionalFormattingIconSetTypeType,
    ConstantTypeType,
    CrossDatasetTypesType,
    CustomContentImageScalingConfigurationType,
    CustomContentTypeType,
    DashboardBehaviorType,
    DashboardErrorTypeType,
    DashboardFilterAttributeType,
    DashboardUIStateType,
    DataLabelContentType,
    DataLabelOverlapType,
    DataLabelPositionType,
    DataSetFilterAttributeType,
    DataSetImportModeType,
    DataSourceErrorInfoTypeType,
    DataSourceFilterAttributeType,
    DataSourceTypeType,
    DatasetParameterValueTypeType,
    DateAggregationFunctionType,
    DayOfWeekType,
    DefaultAggregationType,
    DisplayFormatType,
    EditionType,
    EmbeddingIdentityTypeType,
    FileFormatType,
    FilterClassType,
    FilterNullOptionType,
    FilterOperatorType,
    FilterVisualScopeType,
    FolderFilterAttributeType,
    FolderTypeType,
    FontDecorationType,
    FontStyleType,
    FontWeightNameType,
    ForecastComputationSeasonalityType,
    FunnelChartMeasureDataLabelStyleType,
    GeoSpatialCountryCodeType,
    GeoSpatialDataRoleType,
    GeospatialSelectedPointStyleType,
    GroupFilterAttributeType,
    GroupFilterOperatorType,
    HistogramBinTypeType,
    HorizontalTextAlignmentType,
    IconType,
    IdentityStoreType,
    IdentityTypeType,
    IngestionErrorTypeType,
    IngestionRequestSourceType,
    IngestionRequestTypeType,
    IngestionStatusType,
    IngestionTypeType,
    InputColumnDataTypeType,
    JoinTypeType,
    LayoutElementTypeType,
    LegendPositionType,
    LineChartLineStyleType,
    LineChartMarkerShapeType,
    LineChartTypeType,
    LineInterpolationType,
    ListAnalysesPaginatorName,
    ListAssetBundleExportJobsPaginatorName,
    ListAssetBundleImportJobsPaginatorName,
    ListDashboardVersionsPaginatorName,
    ListDashboardsPaginatorName,
    ListDataSetsPaginatorName,
    ListDataSourcesPaginatorName,
    ListGroupMembershipsPaginatorName,
    ListGroupsPaginatorName,
    ListIAMPolicyAssignmentsForUserPaginatorName,
    ListIAMPolicyAssignmentsPaginatorName,
    ListIngestionsPaginatorName,
    ListNamespacesPaginatorName,
    ListTemplateAliasesPaginatorName,
    ListTemplateVersionsPaginatorName,
    ListTemplatesPaginatorName,
    ListThemeVersionsPaginatorName,
    ListThemesPaginatorName,
    ListUserGroupsPaginatorName,
    ListUsersPaginatorName,
    LookbackWindowSizeUnitType,
    MapZoomModeType,
    MaximumMinimumComputationTypeType,
    MemberTypeType,
    MissingDataTreatmentOptionType,
    NamedEntityAggTypeType,
    NamedFilterAggTypeType,
    NamedFilterTypeType,
    NamespaceErrorTypeType,
    NamespaceStatusType,
    NegativeValueDisplayModeType,
    NetworkInterfaceStatusType,
    NumberScaleType,
    NumericEqualityMatchOperatorType,
    NumericFilterSelectAllOptionsType,
    NumericSeparatorSymbolType,
    OtherCategoriesType,
    PanelBorderStyleType,
    PaperOrientationType,
    PaperSizeType,
    ParameterValueTypeType,
    PivotTableConditionalFormattingScopeRoleType,
    PivotTableFieldCollapseStateType,
    PivotTableMetricPlacementType,
    PivotTableSubtotalLevelType,
    PrimaryValueDisplayTypeType,
    PropertyRoleType,
    PropertyUsageType,
    RadarChartAxesRangeScaleType,
    RadarChartShapeType,
    ReferenceLineLabelHorizontalPositionType,
    ReferenceLineLabelVerticalPositionType,
    ReferenceLinePatternTypeType,
    ReferenceLineValueLabelRelativePositionType,
    RefreshIntervalType,
    RelativeDateTypeType,
    RelativeFontSizeType,
    ResizeOptionType,
    ResourceStatusType,
    RowLevelPermissionFormatVersionType,
    RowLevelPermissionPolicyType,
    SearchAnalysesPaginatorName,
    SearchDashboardsPaginatorName,
    SearchDataSetsPaginatorName,
    SearchDataSourcesPaginatorName,
    SearchGroupsPaginatorName,
    SectionPageBreakStatusType,
    SelectAllValueOptionsType,
    SelectedFieldOptionsType,
    SelectedTooltipTypeType,
    SheetContentTypeType,
    SheetControlDateTimePickerTypeType,
    SheetControlListTypeType,
    SheetControlSliderTypeType,
    SimpleAttributeAggregationFunctionType,
    SimpleNumericalAggregationFunctionType,
    SmallMultiplesAxisPlacementType,
    SmallMultiplesAxisScaleType,
    SnapshotFileFormatTypeType,
    SnapshotFileSheetSelectionScopeType,
    SnapshotJobStatusType,
    SortDirectionType,
    SpecialValueType,
    StatusType,
    TableBorderStyleType,
    TableCellImageScalingConfigurationType,
    TableFieldIconSetTypeType,
    TableOrientationType,
    TableTotalsPlacementType,
    TableTotalsScrollStatusType,
    TargetVisualOptionsType,
    TemplateErrorTypeType,
    TextQualifierType,
    TextWrapType,
    ThemeErrorTypeType,
    ThemeTypeType,
    TimeGranularityType,
    TooltipTitleTypeType,
    TopBottomComputationTypeType,
    TopBottomSortOrderType,
    TopicNumericSeparatorSymbolType,
    TopicRefreshStatusType,
    TopicRelativeDateFilterFunctionType,
    TopicScheduleTypeType,
    TopicTimeGranularityType,
    URLTargetConfigurationType,
    UndefinedSpecifiedValueTypeType,
    UserRoleType,
    VPCConnectionAvailabilityStatusType,
    VPCConnectionResourceStatusType,
    ValueWhenUnsetOptionType,
    VerticalTextAlignmentType,
    VisibilityType,
    VisualCustomActionTriggerType,
    WidgetStatusType,
    WordCloudCloudLayoutType,
    WordCloudWordCasingType,
    WordCloudWordOrientationType,
    WordCloudWordPaddingType,
    WordCloudWordScalingType,
    QuickSightServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: AnalysisErrorTypeType) -> bool:
    ...
```

<a id="type-definitions"></a>

### Type definitions

`mypy_boto3_quicksight.type_defs` module contains structures and shapes
assembled to typed dictionaries and unions for additional type checking.

```python
from mypy_boto3_quicksight.type_defs import (
    AccountCustomizationTypeDef,
    AccountInfoTypeDef,
    AccountSettingsTypeDef,
    ActiveIAMPolicyAssignmentTypeDef,
    AdHocFilteringOptionTypeDef,
    AttributeAggregationFunctionTypeDef,
    ColumnIdentifierTypeDef,
    AmazonElasticsearchParametersTypeDef,
    AmazonOpenSearchParametersTypeDef,
    CalculatedFieldTypeDef,
    DataSetIdentifierDeclarationTypeDef,
    EntityTypeDef,
    AnalysisSearchFilterTypeDef,
    DataSetReferenceTypeDef,
    AnalysisSummaryTypeDef,
    SheetTypeDef,
    AnchorDateConfigurationTypeDef,
    AnonymousUserDashboardEmbeddingConfigurationTypeDef,
    DashboardVisualIdTypeDef,
    AnonymousUserQSearchBarEmbeddingConfigurationTypeDef,
    ArcAxisDisplayRangeTypeDef,
    ArcConfigurationTypeDef,
    ArcOptionsTypeDef,
    AssetBundleExportJobAnalysisOverridePropertiesOutputTypeDef,
    AssetBundleExportJobDashboardOverridePropertiesOutputTypeDef,
    AssetBundleExportJobDataSetOverridePropertiesOutputTypeDef,
    AssetBundleExportJobDataSourceOverridePropertiesOutputTypeDef,
    AssetBundleExportJobRefreshScheduleOverridePropertiesOutputTypeDef,
    AssetBundleExportJobResourceIdOverrideConfigurationTypeDef,
    AssetBundleExportJobThemeOverridePropertiesOutputTypeDef,
    AssetBundleExportJobVPCConnectionOverridePropertiesOutputTypeDef,
    AssetBundleExportJobAnalysisOverridePropertiesTypeDef,
    AssetBundleExportJobDashboardOverridePropertiesTypeDef,
    AssetBundleExportJobDataSetOverridePropertiesTypeDef,
    AssetBundleExportJobDataSourceOverridePropertiesTypeDef,
    AssetBundleExportJobRefreshScheduleOverridePropertiesTypeDef,
    AssetBundleExportJobThemeOverridePropertiesTypeDef,
    AssetBundleExportJobVPCConnectionOverridePropertiesTypeDef,
    AssetBundleExportJobErrorTypeDef,
    AssetBundleExportJobSummaryTypeDef,
    AssetBundleImportJobAnalysisOverrideParametersTypeDef,
    AssetBundleImportJobDashboardOverrideParametersTypeDef,
    AssetBundleImportJobDataSetOverrideParametersTypeDef,
    AssetBundleImportJobDataSourceCredentialPairTypeDef,
    SslPropertiesTypeDef,
    VpcConnectionPropertiesTypeDef,
    AssetBundleImportJobErrorTypeDef,
    AssetBundleImportJobRefreshScheduleOverrideParametersOutputTypeDef,
    AssetBundleImportJobResourceIdOverrideConfigurationTypeDef,
    AssetBundleImportJobThemeOverrideParametersTypeDef,
    AssetBundleImportJobVPCConnectionOverrideParametersOutputTypeDef,
    AssetBundleImportJobVPCConnectionOverrideParametersTypeDef,
    TimestampTypeDef,
    AssetBundleImportJobSummaryTypeDef,
    AssetBundleImportSourceDescriptionTypeDef,
    BlobTypeDef,
    AthenaParametersTypeDef,
    AuroraParametersTypeDef,
    AuroraPostgreSqlParametersTypeDef,
    AwsIotAnalyticsParametersTypeDef,
    DateAxisOptionsTypeDef,
    AxisDisplayMinMaxRangeTypeDef,
    AxisLinearScaleTypeDef,
    AxisLogarithmicScaleTypeDef,
    ItemsLimitConfigurationTypeDef,
    BinCountOptionsTypeDef,
    BinWidthOptionsTypeDef,
    BookmarksConfigurationsTypeDef,
    BorderStyleTypeDef,
    BoxPlotStyleOptionsTypeDef,
    PaginationConfigurationTypeDef,
    CalculatedColumnTypeDef,
    CalculatedMeasureFieldTypeDef,
    CancelIngestionRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    CastColumnTypeOperationTypeDef,
    CustomFilterConfigurationTypeDef,
    CustomFilterListConfigurationOutputTypeDef,
    FilterListConfigurationOutputTypeDef,
    CustomFilterListConfigurationTypeDef,
    FilterListConfigurationTypeDef,
    CellValueSynonymOutputTypeDef,
    CellValueSynonymTypeDef,
    SimpleClusterMarkerTypeDef,
    CollectiveConstantOutputTypeDef,
    CollectiveConstantTypeDef,
    DataColorTypeDef,
    CustomColorTypeDef,
    ColumnDescriptionTypeDef,
    ColumnGroupColumnSchemaTypeDef,
    GeoSpatialColumnGroupOutputTypeDef,
    GeoSpatialColumnGroupTypeDef,
    ColumnLevelPermissionRuleOutputTypeDef,
    ColumnLevelPermissionRuleTypeDef,
    ColumnSchemaTypeDef,
    ComparativeOrderOutputTypeDef,
    ComparativeOrderTypeDef,
    ConditionalFormattingSolidColorTypeDef,
    ConditionalFormattingCustomIconOptionsTypeDef,
    ConditionalFormattingIconDisplayConfigurationTypeDef,
    ConditionalFormattingIconSetTypeDef,
    TagTypeDef,
    CreateAccountSubscriptionRequestRequestTypeDef,
    SignupResponseTypeDef,
    DataSetUsageConfigurationTypeDef,
    RowLevelPermissionDataSetTypeDef,
    CreateFolderMembershipRequestRequestTypeDef,
    FolderMemberTypeDef,
    CreateGroupMembershipRequestRequestTypeDef,
    GroupMemberTypeDef,
    CreateGroupRequestRequestTypeDef,
    GroupTypeDef,
    CreateIAMPolicyAssignmentRequestRequestTypeDef,
    CreateIngestionRequestRequestTypeDef,
    CreateTemplateAliasRequestRequestTypeDef,
    TemplateAliasTypeDef,
    CreateThemeAliasRequestRequestTypeDef,
    ThemeAliasTypeDef,
    DecimalPlacesConfigurationTypeDef,
    NegativeValueConfigurationTypeDef,
    NullValueFormatConfigurationTypeDef,
    LocalNavigationConfigurationTypeDef,
    CustomActionURLOperationTypeDef,
    CustomContentConfigurationTypeDef,
    CustomNarrativeOptionsTypeDef,
    CustomParameterValuesOutputTypeDef,
    InputColumnTypeDef,
    DataPointDrillUpDownOptionTypeDef,
    DataPointMenuLabelOptionTypeDef,
    DataPointTooltipOptionTypeDef,
    ExportToCSVOptionTypeDef,
    ExportWithHiddenFieldsOptionTypeDef,
    SheetControlsOptionTypeDef,
    SheetLayoutElementMaximizationOptionTypeDef,
    VisualAxisSortOptionTypeDef,
    VisualMenuOptionTypeDef,
    DashboardSearchFilterTypeDef,
    DashboardSummaryTypeDef,
    DashboardVersionSummaryTypeDef,
    ExportHiddenFieldsOptionTypeDef,
    DataAggregationTypeDef,
    DataBarsOptionsTypeDef,
    DataColorPaletteOutputTypeDef,
    DataColorPaletteTypeDef,
    DataPathLabelTypeTypeDef,
    FieldLabelTypeTypeDef,
    MaximumLabelTypeTypeDef,
    MinimumLabelTypeTypeDef,
    RangeEndsLabelTypeTypeDef,
    DataPathValueTypeDef,
    DataSetSearchFilterTypeDef,
    FieldFolderOutputTypeDef,
    OutputColumnTypeDef,
    DataSourceErrorInfoTypeDef,
    DatabricksParametersTypeDef,
    ExasolParametersTypeDef,
    JiraParametersTypeDef,
    MariaDbParametersTypeDef,
    MySqlParametersTypeDef,
    OracleParametersTypeDef,
    PostgreSqlParametersTypeDef,
    PrestoParametersTypeDef,
    RdsParametersTypeDef,
    RedshiftParametersTypeDef,
    ServiceNowParametersTypeDef,
    SnowflakeParametersTypeDef,
    SparkParametersTypeDef,
    SqlServerParametersTypeDef,
    TeradataParametersTypeDef,
    TwitterParametersTypeDef,
    DataSourceSearchFilterTypeDef,
    DataSourceSummaryTypeDef,
    DateTimeDatasetParameterDefaultValuesOutputTypeDef,
    RollingDateConfigurationTypeDef,
    DateTimeValueWhenUnsetConfigurationOutputTypeDef,
    MappedDataSetParameterTypeDef,
    DateTimeParameterOutputTypeDef,
    SheetControlInfoIconLabelOptionsTypeDef,
    DecimalDatasetParameterDefaultValuesOutputTypeDef,
    DecimalDatasetParameterDefaultValuesTypeDef,
    DecimalValueWhenUnsetConfigurationTypeDef,
    DecimalParameterOutputTypeDef,
    DecimalParameterTypeDef,
    DeleteAccountCustomizationRequestRequestTypeDef,
    DeleteAccountSubscriptionRequestRequestTypeDef,
    DeleteAnalysisRequestRequestTypeDef,
    DeleteDashboardRequestRequestTypeDef,
    DeleteDataSetRefreshPropertiesRequestRequestTypeDef,
    DeleteDataSetRequestRequestTypeDef,
    DeleteDataSourceRequestRequestTypeDef,
    DeleteFolderMembershipRequestRequestTypeDef,
    DeleteFolderRequestRequestTypeDef,
    DeleteGroupMembershipRequestRequestTypeDef,
    DeleteGroupRequestRequestTypeDef,
    DeleteIAMPolicyAssignmentRequestRequestTypeDef,
    DeleteNamespaceRequestRequestTypeDef,
    DeleteRefreshScheduleRequestRequestTypeDef,
    DeleteTemplateAliasRequestRequestTypeDef,
    DeleteTemplateRequestRequestTypeDef,
    DeleteThemeAliasRequestRequestTypeDef,
    DeleteThemeRequestRequestTypeDef,
    DeleteTopicRefreshScheduleRequestRequestTypeDef,
    DeleteTopicRequestRequestTypeDef,
    DeleteUserByPrincipalIdRequestRequestTypeDef,
    DeleteUserRequestRequestTypeDef,
    DeleteVPCConnectionRequestRequestTypeDef,
    DescribeAccountCustomizationRequestRequestTypeDef,
    DescribeAccountSettingsRequestRequestTypeDef,
    DescribeAccountSubscriptionRequestRequestTypeDef,
    DescribeAnalysisDefinitionRequestRequestTypeDef,
    DescribeAnalysisPermissionsRequestRequestTypeDef,
    ResourcePermissionOutputTypeDef,
    DescribeAnalysisRequestRequestTypeDef,
    DescribeAssetBundleExportJobRequestRequestTypeDef,
    DescribeAssetBundleImportJobRequestRequestTypeDef,
    DescribeDashboardDefinitionRequestRequestTypeDef,
    DescribeDashboardPermissionsRequestRequestTypeDef,
    DescribeDashboardRequestRequestTypeDef,
    DescribeDashboardSnapshotJobRequestRequestTypeDef,
    DescribeDashboardSnapshotJobResultRequestRequestTypeDef,
    SnapshotJobErrorInfoTypeDef,
    DescribeDataSetPermissionsRequestRequestTypeDef,
    DescribeDataSetRefreshPropertiesRequestRequestTypeDef,
    DescribeDataSetRequestRequestTypeDef,
    DescribeDataSourcePermissionsRequestRequestTypeDef,
    DescribeDataSourceRequestRequestTypeDef,
    DescribeFolderPermissionsRequestRequestTypeDef,
    DescribeFolderRequestRequestTypeDef,
    DescribeFolderResolvedPermissionsRequestRequestTypeDef,
    FolderTypeDef,
    DescribeGroupMembershipRequestRequestTypeDef,
    DescribeGroupRequestRequestTypeDef,
    DescribeIAMPolicyAssignmentRequestRequestTypeDef,
    IAMPolicyAssignmentTypeDef,
    DescribeIngestionRequestRequestTypeDef,
    DescribeIpRestrictionRequestRequestTypeDef,
    DescribeNamespaceRequestRequestTypeDef,
    DescribeRefreshScheduleRequestRequestTypeDef,
    DescribeTemplateAliasRequestRequestTypeDef,
    DescribeTemplateDefinitionRequestRequestTypeDef,
    DescribeTemplatePermissionsRequestRequestTypeDef,
    DescribeTemplateRequestRequestTypeDef,
    DescribeThemeAliasRequestRequestTypeDef,
    DescribeThemePermissionsRequestRequestTypeDef,
    DescribeThemeRequestRequestTypeDef,
    DescribeTopicPermissionsRequestRequestTypeDef,
    DescribeTopicRefreshRequestRequestTypeDef,
    TopicRefreshDetailsTypeDef,
    DescribeTopicRefreshScheduleRequestRequestTypeDef,
    TopicRefreshScheduleOutputTypeDef,
    DescribeTopicRequestRequestTypeDef,
    DescribeUserRequestRequestTypeDef,
    UserTypeDef,
    DescribeVPCConnectionRequestRequestTypeDef,
    NegativeFormatTypeDef,
    DonutCenterOptionsTypeDef,
    ListControlSelectAllOptionsTypeDef,
    ErrorInfoTypeDef,
    ExcludePeriodConfigurationTypeDef,
    FieldFolderTypeDef,
    FieldSortTypeDef,
    FieldTooltipItemTypeDef,
    GeospatialMapStyleOptionsTypeDef,
    FilterSelectableValuesOutputTypeDef,
    FilterSelectableValuesTypeDef,
    SameSheetTargetVisualConfigurationOutputTypeDef,
    SameSheetTargetVisualConfigurationTypeDef,
    FilterOperationTypeDef,
    FolderSearchFilterTypeDef,
    FolderSummaryTypeDef,
    FontSizeTypeDef,
    FontWeightTypeDef,
    FontTypeDef,
    TimeBasedForecastPropertiesTypeDef,
    WhatIfPointScenarioOutputTypeDef,
    WhatIfRangeScenarioOutputTypeDef,
    FreeFormLayoutScreenCanvasSizeOptionsTypeDef,
    FreeFormLayoutElementBackgroundStyleTypeDef,
    FreeFormLayoutElementBorderStyleTypeDef,
    LoadingAnimationTypeDef,
    SessionTagTypeDef,
    GeospatialCoordinateBoundsTypeDef,
    GeospatialHeatmapDataColorTypeDef,
    GetDashboardEmbedUrlRequestRequestTypeDef,
    GetSessionEmbedUrlRequestRequestTypeDef,
    TableBorderOptionsTypeDef,
    GradientStopTypeDef,
    GridLayoutScreenCanvasSizeOptionsTypeDef,
    GridLayoutElementTypeDef,
    GroupSearchFilterTypeDef,
    GutterStyleTypeDef,
    IAMPolicyAssignmentSummaryTypeDef,
    LookbackWindowTypeDef,
    QueueInfoTypeDef,
    RowInfoTypeDef,
    IntegerDatasetParameterDefaultValuesOutputTypeDef,
    IntegerDatasetParameterDefaultValuesTypeDef,
    IntegerValueWhenUnsetConfigurationTypeDef,
    IntegerParameterOutputTypeDef,
    IntegerParameterTypeDef,
    JoinKeyPropertiesTypeDef,
    ProgressBarOptionsTypeDef,
    SecondaryValueOptionsTypeDef,
    TrendArrowOptionsTypeDef,
    LineChartLineStyleSettingsTypeDef,
    LineChartMarkerStyleSettingsTypeDef,
    MissingDataConfigurationTypeDef,
    PaginatorConfigTypeDef,
    ListAnalysesRequestRequestTypeDef,
    ListAssetBundleExportJobsRequestRequestTypeDef,
    ListAssetBundleImportJobsRequestRequestTypeDef,
    ListControlSearchOptionsTypeDef,
    ListDashboardVersionsRequestRequestTypeDef,
    ListDashboardsRequestRequestTypeDef,
    ListDataSetsRequestRequestTypeDef,
    ListDataSourcesRequestRequestTypeDef,
    ListFolderMembersRequestRequestTypeDef,
    MemberIdArnPairTypeDef,
    ListFoldersRequestRequestTypeDef,
    ListGroupMembershipsRequestRequestTypeDef,
    ListGroupsRequestRequestTypeDef,
    ListIAMPolicyAssignmentsForUserRequestRequestTypeDef,
    ListIAMPolicyAssignmentsRequestRequestTypeDef,
    ListIngestionsRequestRequestTypeDef,
    ListNamespacesRequestRequestTypeDef,
    ListRefreshSchedulesRequestRequestTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTemplateAliasesRequestRequestTypeDef,
    ListTemplateVersionsRequestRequestTypeDef,
    TemplateVersionSummaryTypeDef,
    ListTemplatesRequestRequestTypeDef,
    TemplateSummaryTypeDef,
    ListThemeAliasesRequestRequestTypeDef,
    ListThemeVersionsRequestRequestTypeDef,
    ThemeVersionSummaryTypeDef,
    ListThemesRequestRequestTypeDef,
    ThemeSummaryTypeDef,
    ListTopicRefreshSchedulesRequestRequestTypeDef,
    ListTopicsRequestRequestTypeDef,
    TopicSummaryTypeDef,
    ListUserGroupsRequestRequestTypeDef,
    ListUsersRequestRequestTypeDef,
    ListVPCConnectionsRequestRequestTypeDef,
    LongFormatTextTypeDef,
    ManifestFileLocationTypeDef,
    MarginStyleTypeDef,
    NamedEntityDefinitionMetricOutputTypeDef,
    NamedEntityDefinitionMetricTypeDef,
    NamespaceErrorTypeDef,
    NetworkInterfaceTypeDef,
    NewDefaultValuesOutputTypeDef,
    NumericRangeFilterValueTypeDef,
    ThousandSeparatorOptionsTypeDef,
    PercentileAggregationTypeDef,
    StringParameterOutputTypeDef,
    StringParameterTypeDef,
    PercentVisibleRangeTypeDef,
    PivotTableConditionalFormattingScopeTypeDef,
    PivotTablePaginatedReportOptionsTypeDef,
    PivotTableFieldOptionTypeDef,
    PivotTableFieldSubtotalOptionsTypeDef,
    RowAlternateColorOptionsOutputTypeDef,
    RowAlternateColorOptionsTypeDef,
    ProjectOperationOutputTypeDef,
    ProjectOperationTypeDef,
    RadarChartAreaStyleSettingsTypeDef,
    RangeConstantTypeDef,
    ReferenceLineCustomLabelConfigurationTypeDef,
    ReferenceLineStaticDataConfigurationTypeDef,
    ReferenceLineStyleConfigurationTypeDef,
    ScheduleRefreshOnEntityTypeDef,
    RegisterUserRequestRequestTypeDef,
    StatePersistenceConfigurationsTypeDef,
    RegisteredUserQSearchBarEmbeddingConfigurationTypeDef,
    RenameColumnOperationTypeDef,
    ResourcePermissionTypeDef,
    RestoreAnalysisRequestRequestTypeDef,
    RowLevelPermissionTagRuleTypeDef,
    S3BucketConfigurationTypeDef,
    UploadSettingsTypeDef,
    SectionAfterPageBreakTypeDef,
    SpacingTypeDef,
    SheetVisualScopingConfigurationOutputTypeDef,
    SheetVisualScopingConfigurationTypeDef,
    SemanticEntityTypeOutputTypeDef,
    SemanticEntityTypeTypeDef,
    SemanticTypeOutputTypeDef,
    SemanticTypeTypeDef,
    SheetTextBoxTypeDef,
    SheetElementConfigurationOverridesTypeDef,
    ShortFormatTextTypeDef,
    SmallMultiplesAxisPropertiesTypeDef,
    SnapshotAnonymousUserRedactedTypeDef,
    SnapshotFileSheetSelectionOutputTypeDef,
    SnapshotFileSheetSelectionTypeDef,
    SnapshotJobResultErrorInfoTypeDef,
    StringDatasetParameterDefaultValuesOutputTypeDef,
    StringDatasetParameterDefaultValuesTypeDef,
    StringValueWhenUnsetConfigurationTypeDef,
    TableCellImageSizingConfigurationTypeDef,
    TablePaginatedReportOptionsTypeDef,
    TableFieldCustomIconContentTypeDef,
    TemplateSourceTemplateTypeDef,
    TextControlPlaceholderOptionsTypeDef,
    UIColorPaletteTypeDef,
    ThemeErrorTypeDef,
    TopicSingularFilterConstantTypeDef,
    UntagColumnOperationOutputTypeDef,
    UntagColumnOperationTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateAccountSettingsRequestRequestTypeDef,
    UpdateDashboardPublishedVersionRequestRequestTypeDef,
    UpdateFolderRequestRequestTypeDef,
    UpdateGroupRequestRequestTypeDef,
    UpdateIAMPolicyAssignmentRequestRequestTypeDef,
    UpdateIpRestrictionRequestRequestTypeDef,
    UpdatePublicSharingSettingsRequestRequestTypeDef,
    UpdateTemplateAliasRequestRequestTypeDef,
    UpdateThemeAliasRequestRequestTypeDef,
    UpdateUserRequestRequestTypeDef,
    UpdateVPCConnectionRequestRequestTypeDef,
    WaterfallChartOptionsTypeDef,
    WordCloudOptionsTypeDef,
    UpdateAccountCustomizationRequestRequestTypeDef,
    AxisLabelReferenceOptionsTypeDef,
    CascadingControlSourceTypeDef,
    CategoryDrillDownFilterOutputTypeDef,
    CategoryDrillDownFilterTypeDef,
    ContributionAnalysisDefaultOutputTypeDef,
    ContributionAnalysisDefaultTypeDef,
    DynamicDefaultValueTypeDef,
    FilterOperationSelectedFieldsConfigurationOutputTypeDef,
    FilterOperationSelectedFieldsConfigurationTypeDef,
    NumericEqualityDrillDownFilterTypeDef,
    ParameterSelectableValuesOutputTypeDef,
    ParameterSelectableValuesTypeDef,
    TimeEqualityFilterOutputTypeDef,
    TimeRangeDrillDownFilterOutputTypeDef,
    AnalysisErrorTypeDef,
    DashboardErrorTypeDef,
    TemplateErrorTypeDef,
    SearchAnalysesRequestRequestTypeDef,
    AnalysisSourceTemplateTypeDef,
    DashboardSourceTemplateTypeDef,
    TemplateSourceAnalysisTypeDef,
    AnonymousUserDashboardVisualEmbeddingConfigurationTypeDef,
    RegisteredUserDashboardVisualEmbeddingConfigurationTypeDef,
    ArcAxisConfigurationTypeDef,
    AssetBundleCloudFormationOverridePropertyConfigurationOutputTypeDef,
    AssetBundleCloudFormationOverridePropertyConfigurationTypeDef,
    AssetBundleImportJobDataSourceCredentialsTypeDef,
    AssetBundleImportJobRefreshScheduleOverrideParametersTypeDef,
    CustomParameterValuesTypeDef,
    DateTimeDatasetParameterDefaultValuesTypeDef,
    DateTimeParameterTypeDef,
    DateTimeValueWhenUnsetConfigurationTypeDef,
    NewDefaultValuesTypeDef,
    TimeEqualityFilterTypeDef,
    TimeRangeDrillDownFilterTypeDef,
    TopicRefreshScheduleTypeDef,
    WhatIfPointScenarioTypeDef,
    WhatIfRangeScenarioTypeDef,
    AssetBundleImportSourceTypeDef,
    AxisDisplayRangeOutputTypeDef,
    AxisDisplayRangeTypeDef,
    AxisScaleTypeDef,
    HistogramBinOptionsTypeDef,
    TileStyleTypeDef,
    BoxPlotOptionsTypeDef,
    CreateColumnsOperationOutputTypeDef,
    CreateColumnsOperationTypeDef,
    CancelIngestionResponseTypeDef,
    CreateAccountCustomizationResponseTypeDef,
    CreateAnalysisResponseTypeDef,
    CreateDashboardResponseTypeDef,
    CreateDataSetResponseTypeDef,
    CreateDataSourceResponseTypeDef,
    CreateFolderResponseTypeDef,
    CreateIAMPolicyAssignmentResponseTypeDef,
    CreateIngestionResponseTypeDef,
    CreateNamespaceResponseTypeDef,
    CreateRefreshScheduleResponseTypeDef,
    CreateTemplateResponseTypeDef,
    CreateThemeResponseTypeDef,
    CreateTopicRefreshScheduleResponseTypeDef,
    CreateTopicResponseTypeDef,
    CreateVPCConnectionResponseTypeDef,
    DeleteAccountCustomizationResponseTypeDef,
    DeleteAccountSubscriptionResponseTypeDef,
    DeleteAnalysisResponseTypeDef,
    DeleteDashboardResponseTypeDef,
    DeleteDataSetRefreshPropertiesResponseTypeDef,
    DeleteDataSetResponseTypeDef,
    DeleteDataSourceResponseTypeDef,
    DeleteFolderMembershipResponseTypeDef,
    DeleteFolderResponseTypeDef,
    DeleteGroupMembershipResponseTypeDef,
    DeleteGroupResponseTypeDef,
    DeleteIAMPolicyAssignmentResponseTypeDef,
    DeleteNamespaceResponseTypeDef,
    DeleteRefreshScheduleResponseTypeDef,
    DeleteTemplateAliasResponseTypeDef,
    DeleteTemplateResponseTypeDef,
    DeleteThemeAliasResponseTypeDef,
    DeleteThemeResponseTypeDef,
    DeleteTopicRefreshScheduleResponseTypeDef,
    DeleteTopicResponseTypeDef,
    DeleteUserByPrincipalIdResponseTypeDef,
    DeleteUserResponseTypeDef,
    DeleteVPCConnectionResponseTypeDef,
    DescribeAccountCustomizationResponseTypeDef,
    DescribeAccountSettingsResponseTypeDef,
    DescribeAccountSubscriptionResponseTypeDef,
    DescribeIpRestrictionResponseTypeDef,
    GenerateEmbedUrlForAnonymousUserResponseTypeDef,
    GenerateEmbedUrlForRegisteredUserResponseTypeDef,
    GetDashboardEmbedUrlResponseTypeDef,
    GetSessionEmbedUrlResponseTypeDef,
    ListAnalysesResponseTypeDef,
    ListAssetBundleExportJobsResponseTypeDef,
    ListAssetBundleImportJobsResponseTypeDef,
    ListIAMPolicyAssignmentsForUserResponseTypeDef,
    PutDataSetRefreshPropertiesResponseTypeDef,
    RestoreAnalysisResponseTypeDef,
    SearchAnalysesResponseTypeDef,
    StartAssetBundleExportJobResponseTypeDef,
    StartAssetBundleImportJobResponseTypeDef,
    StartDashboardSnapshotJobResponseTypeDef,
    TagResourceResponseTypeDef,
    UntagResourceResponseTypeDef,
    UpdateAccountCustomizationResponseTypeDef,
    UpdateAccountSettingsResponseTypeDef,
    UpdateAnalysisResponseTypeDef,
    UpdateDashboardPublishedVersionResponseTypeDef,
    UpdateDashboardResponseTypeDef,
    UpdateDataSetPermissionsResponseTypeDef,
    UpdateDataSetResponseTypeDef,
    UpdateDataSourcePermissionsResponseTypeDef,
    UpdateDataSourceResponseTypeDef,
    UpdateFolderResponseTypeDef,
    UpdateIAMPolicyAssignmentResponseTypeDef,
    UpdateIpRestrictionResponseTypeDef,
    UpdatePublicSharingSettingsResponseTypeDef,
    UpdateRefreshScheduleResponseTypeDef,
    UpdateTemplateResponseTypeDef,
    UpdateThemeResponseTypeDef,
    UpdateTopicRefreshScheduleResponseTypeDef,
    UpdateTopicResponseTypeDef,
    UpdateVPCConnectionResponseTypeDef,
    CategoryFilterConfigurationOutputTypeDef,
    CategoryFilterConfigurationTypeDef,
    ClusterMarkerTypeDef,
    TopicCategoryFilterConstantOutputTypeDef,
    TopicCategoryFilterConstantTypeDef,
    ColorScaleOutputTypeDef,
    ColorScaleTypeDef,
    ColorsConfigurationOutputTypeDef,
    ColorsConfigurationTypeDef,
    ColumnTagTypeDef,
    ColumnGroupSchemaOutputTypeDef,
    ColumnGroupSchemaTypeDef,
    ColumnGroupOutputTypeDef,
    ColumnGroupTypeDef,
    ColumnLevelPermissionRuleUnionTypeDef,
    DataSetSchemaOutputTypeDef,
    DataSetSchemaTypeDef,
    ConditionalFormattingCustomIconConditionTypeDef,
    CreateAccountCustomizationRequestRequestTypeDef,
    CreateNamespaceRequestRequestTypeDef,
    CreateVPCConnectionRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    TagResourceRequestRequestTypeDef,
    CreateAccountSubscriptionResponseTypeDef,
    DataSetSummaryTypeDef,
    CreateFolderMembershipResponseTypeDef,
    CreateGroupMembershipResponseTypeDef,
    DescribeGroupMembershipResponseTypeDef,
    ListGroupMembershipsResponseTypeDef,
    CreateGroupResponseTypeDef,
    DescribeGroupResponseTypeDef,
    ListGroupsResponseTypeDef,
    ListUserGroupsResponseTypeDef,
    SearchGroupsResponseTypeDef,
    UpdateGroupResponseTypeDef,
    CreateTemplateAliasResponseTypeDef,
    DescribeTemplateAliasResponseTypeDef,
    ListTemplateAliasesResponseTypeDef,
    UpdateTemplateAliasResponseTypeDef,
    CreateThemeAliasResponseTypeDef,
    DescribeThemeAliasResponseTypeDef,
    ListThemeAliasesResponseTypeDef,
    UpdateThemeAliasResponseTypeDef,
    CustomActionNavigationOperationTypeDef,
    CustomValuesConfigurationOutputTypeDef,
    CustomSqlOutputTypeDef,
    CustomSqlTypeDef,
    RelationalTableOutputTypeDef,
    RelationalTableTypeDef,
    SearchDashboardsRequestRequestTypeDef,
    ListDashboardsResponseTypeDef,
    SearchDashboardsResponseTypeDef,
    ListDashboardVersionsResponseTypeDef,
    DashboardVisualPublishOptionsTypeDef,
    TableInlineVisualizationTypeDef,
    DataLabelTypeTypeDef,
    DataPathColorTypeDef,
    DataPathSortOutputTypeDef,
    DataPathSortTypeDef,
    PivotTableDataPathOptionOutputTypeDef,
    PivotTableDataPathOptionTypeDef,
    PivotTableFieldCollapseStateTargetOutputTypeDef,
    PivotTableFieldCollapseStateTargetTypeDef,
    SearchDataSetsRequestRequestTypeDef,
    SearchDataSourcesRequestRequestTypeDef,
    SearchDataSourcesResponseTypeDef,
    DateTimeDatasetParameterOutputTypeDef,
    TimeRangeFilterValueOutputTypeDef,
    TimeRangeFilterValueTypeDef,
    DecimalDatasetParameterOutputTypeDef,
    DecimalDatasetParameterTypeDef,
    DescribeAnalysisPermissionsResponseTypeDef,
    DescribeDataSetPermissionsResponseTypeDef,
    DescribeDataSourcePermissionsResponseTypeDef,
    DescribeFolderPermissionsResponseTypeDef,
    DescribeFolderResolvedPermissionsResponseTypeDef,
    DescribeTemplatePermissionsResponseTypeDef,
    DescribeThemePermissionsResponseTypeDef,
    DescribeTopicPermissionsResponseTypeDef,
    LinkSharingConfigurationTypeDef,
    UpdateAnalysisPermissionsResponseTypeDef,
    UpdateFolderPermissionsResponseTypeDef,
    UpdateTemplatePermissionsResponseTypeDef,
    UpdateThemePermissionsResponseTypeDef,
    UpdateTopicPermissionsResponseTypeDef,
    DescribeFolderResponseTypeDef,
    DescribeIAMPolicyAssignmentResponseTypeDef,
    DescribeTopicRefreshResponseTypeDef,
    DescribeTopicRefreshScheduleResponseTypeDef,
    TopicRefreshScheduleSummaryTypeDef,
    DescribeUserResponseTypeDef,
    ListUsersResponseTypeDef,
    RegisterUserResponseTypeDef,
    UpdateUserResponseTypeDef,
    DisplayFormatOptionsTypeDef,
    DonutOptionsTypeDef,
    RelativeDatesFilterTypeDef,
    FieldFolderUnionTypeDef,
    FilterOperationTargetVisualsConfigurationOutputTypeDef,
    FilterOperationTargetVisualsConfigurationTypeDef,
    SearchFoldersRequestRequestTypeDef,
    ListFoldersResponseTypeDef,
    SearchFoldersResponseTypeDef,
    FontConfigurationTypeDef,
    TypographyOutputTypeDef,
    TypographyTypeDef,
    ForecastScenarioOutputTypeDef,
    FreeFormLayoutCanvasSizeOptionsTypeDef,
    SnapshotAnonymousUserTypeDef,
    GeospatialWindowOptionsTypeDef,
    GeospatialHeatmapColorScaleOutputTypeDef,
    GeospatialHeatmapColorScaleTypeDef,
    TableSideBorderOptionsTypeDef,
    GradientColorOutputTypeDef,
    GradientColorTypeDef,
    GridLayoutCanvasSizeOptionsTypeDef,
    SearchGroupsRequestRequestTypeDef,
    ListIAMPolicyAssignmentsResponseTypeDef,
    IncrementalRefreshTypeDef,
    IngestionTypeDef,
    IntegerDatasetParameterOutputTypeDef,
    IntegerDatasetParameterTypeDef,
    JoinInstructionTypeDef,
    LineChartDefaultSeriesSettingsTypeDef,
    LineChartSeriesSettingsTypeDef,
    ListAnalysesRequestListAnalysesPaginateTypeDef,
    ListAssetBundleExportJobsRequestListAssetBundleExportJobsPaginateTypeDef,
    ListAssetBundleImportJobsRequestListAssetBundleImportJobsPaginateTypeDef,
    ListDashboardVersionsRequestListDashboardVersionsPaginateTypeDef,
    ListDashboardsRequestListDashboardsPaginateTypeDef,
    ListDataSetsRequestListDataSetsPaginateTypeDef,
    ListDataSourcesRequestListDataSourcesPaginateTypeDef,
    ListGroupMembershipsRequestListGroupMembershipsPaginateTypeDef,
    ListGroupsRequestListGroupsPaginateTypeDef,
    ListIAMPolicyAssignmentsForUserRequestListIAMPolicyAssignmentsForUserPaginateTypeDef,
    ListIAMPolicyAssignmentsRequestListIAMPolicyAssignmentsPaginateTypeDef,
    ListIngestionsRequestListIngestionsPaginateTypeDef,
    ListNamespacesRequestListNamespacesPaginateTypeDef,
    ListTemplateAliasesRequestListTemplateAliasesPaginateTypeDef,
    ListTemplateVersionsRequestListTemplateVersionsPaginateTypeDef,
    ListTemplatesRequestListTemplatesPaginateTypeDef,
    ListThemeVersionsRequestListThemeVersionsPaginateTypeDef,
    ListThemesRequestListThemesPaginateTypeDef,
    ListUserGroupsRequestListUserGroupsPaginateTypeDef,
    ListUsersRequestListUsersPaginateTypeDef,
    SearchAnalysesRequestSearchAnalysesPaginateTypeDef,
    SearchDashboardsRequestSearchDashboardsPaginateTypeDef,
    SearchDataSetsRequestSearchDataSetsPaginateTypeDef,
    SearchDataSourcesRequestSearchDataSourcesPaginateTypeDef,
    SearchGroupsRequestSearchGroupsPaginateTypeDef,
    ListFolderMembersResponseTypeDef,
    ListTemplateVersionsResponseTypeDef,
    ListTemplatesResponseTypeDef,
    ListThemeVersionsResponseTypeDef,
    ListThemesResponseTypeDef,
    ListTopicsResponseTypeDef,
    VisualSubtitleLabelOptionsTypeDef,
    S3ParametersTypeDef,
    TileLayoutStyleTypeDef,
    NamedEntityDefinitionOutputTypeDef,
    NamedEntityDefinitionTypeDef,
    NamespaceInfoV2TypeDef,
    VPCConnectionSummaryTypeDef,
    VPCConnectionTypeDef,
    OverrideDatasetParameterOperationOutputTypeDef,
    NumericSeparatorConfigurationTypeDef,
    NumericalAggregationFunctionTypeDef,
    ParametersOutputTypeDef,
    VisibleRangeOptionsTypeDef,
    RadarChartSeriesSettingsTypeDef,
    TopicRangeFilterConstantTypeDef,
    RefreshFrequencyTypeDef,
    RegisteredUserConsoleFeatureConfigurationsTypeDef,
    RegisteredUserDashboardFeatureConfigurationsTypeDef,
    ResourcePermissionUnionTypeDef,
    RowLevelPermissionTagConfigurationOutputTypeDef,
    RowLevelPermissionTagConfigurationTypeDef,
    SnapshotS3DestinationConfigurationTypeDef,
    S3SourceOutputTypeDef,
    S3SourceTypeDef,
    SectionPageBreakConfigurationTypeDef,
    SectionBasedLayoutPaperCanvasSizeOptionsTypeDef,
    SectionStyleTypeDef,
    SelectedSheetsFilterScopeConfigurationOutputTypeDef,
    SelectedSheetsFilterScopeConfigurationTypeDef,
    SheetElementRenderingRuleTypeDef,
    VisualTitleLabelOptionsTypeDef,
    SnapshotUserConfigurationRedactedTypeDef,
    SnapshotFileOutputTypeDef,
    SnapshotFileTypeDef,
    StringDatasetParameterOutputTypeDef,
    StringDatasetParameterTypeDef,
    TableFieldImageConfigurationTypeDef,
    TopicNumericEqualityFilterTypeDef,
    TopicRelativeDateFilterTypeDef,
    CascadingControlConfigurationOutputTypeDef,
    CascadingControlConfigurationTypeDef,
    DateTimeDefaultValuesOutputTypeDef,
    DateTimeDefaultValuesTypeDef,
    DecimalDefaultValuesOutputTypeDef,
    DecimalDefaultValuesTypeDef,
    IntegerDefaultValuesOutputTypeDef,
    IntegerDefaultValuesTypeDef,
    StringDefaultValuesOutputTypeDef,
    StringDefaultValuesTypeDef,
    DrillDownFilterOutputTypeDef,
    AnalysisTypeDef,
    DashboardVersionTypeDef,
    AnalysisSourceEntityTypeDef,
    DashboardSourceEntityTypeDef,
    TemplateSourceEntityTypeDef,
    AnonymousUserEmbeddingExperienceConfigurationTypeDef,
    DescribeAssetBundleExportJobResponseTypeDef,
    AssetBundleCloudFormationOverridePropertyConfigurationUnionTypeDef,
    StartAssetBundleExportJobRequestRequestTypeDef,
    CustomValuesConfigurationTypeDef,
    DateTimeDatasetParameterTypeDef,
    ParametersTypeDef,
    OverrideDatasetParameterOperationTypeDef,
    DrillDownFilterTypeDef,
    CreateTopicRefreshScheduleRequestRequestTypeDef,
    TopicRefreshScheduleUnionTypeDef,
    UpdateTopicRefreshScheduleRequestRequestTypeDef,
    ForecastScenarioTypeDef,
    NumericAxisOptionsOutputTypeDef,
    NumericAxisOptionsTypeDef,
    CategoryFilterOutputTypeDef,
    CategoryFilterTypeDef,
    ClusterMarkerConfigurationTypeDef,
    TopicCategoryFilterOutputTypeDef,
    TopicCategoryFilterTypeDef,
    TagColumnOperationOutputTypeDef,
    TagColumnOperationTypeDef,
    ColumnGroupUnionTypeDef,
    DataSetConfigurationOutputTypeDef,
    DataSetConfigurationTypeDef,
    ConditionalFormattingIconTypeDef,
    ListDataSetsResponseTypeDef,
    SearchDataSetsResponseTypeDef,
    DestinationParameterValueConfigurationOutputTypeDef,
    DashboardPublishOptionsTypeDef,
    VisualPaletteOutputTypeDef,
    VisualPaletteTypeDef,
    PivotTableFieldCollapseStateOptionOutputTypeDef,
    PivotTableFieldCollapseStateOptionTypeDef,
    TimeRangeFilterOutputTypeDef,
    TimeRangeFilterTypeDef,
    DescribeDashboardPermissionsResponseTypeDef,
    UpdateDashboardPermissionsResponseTypeDef,
    ListTopicRefreshSchedulesResponseTypeDef,
    DefaultFormattingTypeDef,
    CustomActionFilterOperationOutputTypeDef,
    CustomActionFilterOperationTypeDef,
    AxisLabelOptionsTypeDef,
    DataLabelOptionsOutputTypeDef,
    DataLabelOptionsTypeDef,
    FunnelChartDataLabelOptionsTypeDef,
    LabelOptionsTypeDef,
    PanelTitleOptionsTypeDef,
    TableFieldCustomTextContentTypeDef,
    ForecastConfigurationOutputTypeDef,
    DefaultFreeFormLayoutConfigurationTypeDef,
    SnapshotUserConfigurationTypeDef,
    GeospatialHeatmapConfigurationOutputTypeDef,
    GeospatialHeatmapConfigurationTypeDef,
    GlobalTableBorderOptionsTypeDef,
    ConditionalFormattingGradientColorOutputTypeDef,
    ConditionalFormattingGradientColorTypeDef,
    DefaultGridLayoutConfigurationTypeDef,
    GridLayoutConfigurationOutputTypeDef,
    GridLayoutConfigurationTypeDef,
    RefreshConfigurationTypeDef,
    DescribeIngestionResponseTypeDef,
    ListIngestionsResponseTypeDef,
    LogicalTableSourceTypeDef,
    DataFieldSeriesItemTypeDef,
    FieldSeriesItemTypeDef,
    DataSourceParametersTypeDef,
    SheetStyleTypeDef,
    TopicNamedEntityOutputTypeDef,
    TopicNamedEntityTypeDef,
    DescribeNamespaceResponseTypeDef,
    ListNamespacesResponseTypeDef,
    ListVPCConnectionsResponseTypeDef,
    DescribeVPCConnectionResponseTypeDef,
    CurrencyDisplayFormatConfigurationTypeDef,
    NumberDisplayFormatConfigurationTypeDef,
    PercentageDisplayFormatConfigurationTypeDef,
    AggregationFunctionTypeDef,
    ScrollBarOptionsTypeDef,
    TopicDateRangeFilterTypeDef,
    TopicNumericRangeFilterTypeDef,
    RefreshScheduleOutputTypeDef,
    RefreshScheduleTypeDef,
    RegisteredUserQuickSightConsoleEmbeddingConfigurationTypeDef,
    RegisteredUserDashboardEmbeddingConfigurationTypeDef,
    CreateFolderRequestRequestTypeDef,
    UpdateAnalysisPermissionsRequestRequestTypeDef,
    UpdateDashboardPermissionsRequestRequestTypeDef,
    UpdateDataSetPermissionsRequestRequestTypeDef,
    UpdateDataSourcePermissionsRequestRequestTypeDef,
    UpdateFolderPermissionsRequestRequestTypeDef,
    UpdateTemplatePermissionsRequestRequestTypeDef,
    UpdateThemePermissionsRequestRequestTypeDef,
    UpdateTopicPermissionsRequestRequestTypeDef,
    RowLevelPermissionTagConfigurationUnionTypeDef,
    SnapshotDestinationConfigurationOutputTypeDef,
    SnapshotDestinationConfigurationTypeDef,
    SnapshotJobS3ResultTypeDef,
    PhysicalTableOutputTypeDef,
    PhysicalTableTypeDef,
    SectionBasedLayoutCanvasSizeOptionsTypeDef,
    FilterScopeConfigurationOutputTypeDef,
    FilterScopeConfigurationTypeDef,
    FreeFormLayoutElementOutputTypeDef,
    FreeFormLayoutElementTypeDef,
    SnapshotFileGroupOutputTypeDef,
    SnapshotFileGroupTypeDef,
    DatasetParameterOutputTypeDef,
    DateTimeParameterDeclarationOutputTypeDef,
    DateTimeParameterDeclarationTypeDef,
    DecimalParameterDeclarationOutputTypeDef,
    DecimalParameterDeclarationTypeDef,
    IntegerParameterDeclarationOutputTypeDef,
    IntegerParameterDeclarationTypeDef,
    StringParameterDeclarationOutputTypeDef,
    StringParameterDeclarationTypeDef,
    DateTimeHierarchyOutputTypeDef,
    ExplicitHierarchyOutputTypeDef,
    PredefinedHierarchyOutputTypeDef,
    DescribeAnalysisResponseTypeDef,
    DashboardTypeDef,
    GenerateEmbedUrlForAnonymousUserRequestRequestTypeDef,
    DestinationParameterValueConfigurationTypeDef,
    DatasetParameterTypeDef,
    ParametersUnionTypeDef,
    DateTimeHierarchyTypeDef,
    ExplicitHierarchyTypeDef,
    PredefinedHierarchyTypeDef,
    ForecastConfigurationTypeDef,
    AxisDataOptionsOutputTypeDef,
    AxisDataOptionsTypeDef,
    TransformOperationOutputTypeDef,
    TransformOperationTypeDef,
    TemplateVersionTypeDef,
    SetParameterValueConfigurationOutputTypeDef,
    PivotTableFieldOptionsOutputTypeDef,
    PivotTableFieldOptionsTypeDef,
    TopicCalculatedFieldOutputTypeDef,
    TopicCalculatedFieldTypeDef,
    TopicColumnOutputTypeDef,
    TopicColumnTypeDef,
    ChartAxisLabelOptionsOutputTypeDef,
    ChartAxisLabelOptionsTypeDef,
    AxisTickLabelOptionsTypeDef,
    DateTimePickerControlDisplayOptionsTypeDef,
    DropDownControlDisplayOptionsTypeDef,
    LegendOptionsTypeDef,
    ListControlDisplayOptionsTypeDef,
    RelativeDateTimeControlDisplayOptionsTypeDef,
    SliderControlDisplayOptionsTypeDef,
    TextAreaControlDisplayOptionsTypeDef,
    TextFieldControlDisplayOptionsTypeDef,
    PanelConfigurationTypeDef,
    TableFieldLinkContentConfigurationTypeDef,
    GeospatialPointStyleOptionsOutputTypeDef,
    GeospatialPointStyleOptionsTypeDef,
    TableCellStyleTypeDef,
    ConditionalFormattingColorOutputTypeDef,
    ConditionalFormattingColorTypeDef,
    DefaultInteractiveLayoutConfigurationTypeDef,
    SheetControlLayoutConfigurationOutputTypeDef,
    SheetControlLayoutConfigurationTypeDef,
    DataSetRefreshPropertiesTypeDef,
    SeriesItemTypeDef,
    AssetBundleImportJobDataSourceOverrideParametersTypeDef,
    CredentialPairTypeDef,
    DataSourceTypeDef,
    ThemeConfigurationOutputTypeDef,
    ThemeConfigurationTypeDef,
    ComparisonFormatConfigurationTypeDef,
    NumericFormatConfigurationTypeDef,
    AggregationSortConfigurationTypeDef,
    ColumnSortTypeDef,
    ColumnTooltipItemTypeDef,
    NumericEqualityFilterTypeDef,
    NumericRangeFilterTypeDef,
    ReferenceLineDynamicDataConfigurationTypeDef,
    TopicFilterOutputTypeDef,
    TopicFilterTypeDef,
    DescribeRefreshScheduleResponseTypeDef,
    ListRefreshSchedulesResponseTypeDef,
    CreateRefreshScheduleRequestRequestTypeDef,
    RefreshScheduleUnionTypeDef,
    UpdateRefreshScheduleRequestRequestTypeDef,
    RegisteredUserEmbeddingExperienceConfigurationTypeDef,
    SnapshotJobResultFileGroupTypeDef,
    PhysicalTableUnionTypeDef,
    DefaultSectionBasedLayoutConfigurationTypeDef,
    FreeFormLayoutConfigurationOutputTypeDef,
    FreeFormSectionLayoutConfigurationOutputTypeDef,
    FreeFormLayoutConfigurationTypeDef,
    FreeFormSectionLayoutConfigurationTypeDef,
    SnapshotConfigurationOutputTypeDef,
    SnapshotConfigurationTypeDef,
    ParameterDeclarationOutputTypeDef,
    ParameterDeclarationTypeDef,
    ColumnHierarchyOutputTypeDef,
    DescribeDashboardResponseTypeDef,
    SetParameterValueConfigurationTypeDef,
    DatasetParameterUnionTypeDef,
    ColumnHierarchyTypeDef,
    LogicalTableOutputTypeDef,
    LogicalTableTypeDef,
    TemplateTypeDef,
    CustomActionSetParametersOperationOutputTypeDef,
    AxisDisplayOptionsOutputTypeDef,
    AxisDisplayOptionsTypeDef,
    FilterDateTimePickerControlTypeDef,
    ParameterDateTimePickerControlTypeDef,
    FilterDropDownControlOutputTypeDef,
    FilterDropDownControlTypeDef,
    ParameterDropDownControlOutputTypeDef,
    ParameterDropDownControlTypeDef,
    FilterListControlOutputTypeDef,
    FilterListControlTypeDef,
    ParameterListControlOutputTypeDef,
    ParameterListControlTypeDef,
    FilterRelativeDateTimeControlTypeDef,
    FilterSliderControlTypeDef,
    ParameterSliderControlTypeDef,
    FilterTextAreaControlTypeDef,
    ParameterTextAreaControlTypeDef,
    FilterTextFieldControlTypeDef,
    ParameterTextFieldControlTypeDef,
    SmallMultiplesOptionsTypeDef,
    TableFieldLinkConfigurationTypeDef,
    PivotTableOptionsOutputTypeDef,
    PivotTableOptionsTypeDef,
    PivotTotalOptionsTypeDef,
    SubtotalOptionsOutputTypeDef,
    SubtotalOptionsTypeDef,
    TableOptionsOutputTypeDef,
    TableOptionsTypeDef,
    TotalOptionsTypeDef,
    GaugeChartArcConditionalFormattingOutputTypeDef,
    GaugeChartPrimaryValueConditionalFormattingOutputTypeDef,
    KPIPrimaryValueConditionalFormattingOutputTypeDef,
    KPIProgressBarConditionalFormattingOutputTypeDef,
    ShapeConditionalFormatOutputTypeDef,
    TableRowConditionalFormattingOutputTypeDef,
    TextConditionalFormatOutputTypeDef,
    GaugeChartArcConditionalFormattingTypeDef,
    GaugeChartPrimaryValueConditionalFormattingTypeDef,
    KPIPrimaryValueConditionalFormattingTypeDef,
    KPIProgressBarConditionalFormattingTypeDef,
    ShapeConditionalFormatTypeDef,
    TableRowConditionalFormattingTypeDef,
    TextConditionalFormatTypeDef,
    SheetControlLayoutOutputTypeDef,
    SheetControlLayoutTypeDef,
    DescribeDataSetRefreshPropertiesResponseTypeDef,
    PutDataSetRefreshPropertiesRequestRequestTypeDef,
    AssetBundleImportJobOverrideParametersOutputTypeDef,
    AssetBundleImportJobOverrideParametersTypeDef,
    DataSourceCredentialsTypeDef,
    DescribeDataSourceResponseTypeDef,
    ListDataSourcesResponseTypeDef,
    ThemeVersionTypeDef,
    CreateThemeRequestRequestTypeDef,
    ThemeConfigurationUnionTypeDef,
    UpdateThemeRequestRequestTypeDef,
    ComparisonConfigurationTypeDef,
    DateTimeFormatConfigurationTypeDef,
    NumberFormatConfigurationTypeDef,
    ReferenceLineValueLabelConfigurationTypeDef,
    StringFormatConfigurationTypeDef,
    TopBottomFilterOutputTypeDef,
    TopBottomFilterTypeDef,
    FieldSortOptionsTypeDef,
    PivotTableSortByOutputTypeDef,
    PivotTableSortByTypeDef,
    TooltipItemTypeDef,
    ReferenceLineDataConfigurationTypeDef,
    DatasetMetadataOutputTypeDef,
    DatasetMetadataTypeDef,
    GenerateEmbedUrlForRegisteredUserRequestRequestTypeDef,
    AnonymousUserSnapshotJobResultTypeDef,
    DefaultPaginatedLayoutConfigurationTypeDef,
    SectionLayoutConfigurationOutputTypeDef,
    SectionLayoutConfigurationTypeDef,
    DescribeDashboardSnapshotJobResponseTypeDef,
    SnapshotConfigurationUnionTypeDef,
    StartDashboardSnapshotJobRequestRequestTypeDef,
    CustomActionSetParametersOperationTypeDef,
    DataSetTypeDef,
    LogicalTableUnionTypeDef,
    DescribeTemplateResponseTypeDef,
    VisualCustomActionOperationOutputTypeDef,
    LineSeriesAxisDisplayOptionsOutputTypeDef,
    LineSeriesAxisDisplayOptionsTypeDef,
    FilterControlOutputTypeDef,
    FilterControlTypeDef,
    ParameterControlOutputTypeDef,
    ParameterControlTypeDef,
    TableFieldURLConfigurationTypeDef,
    PivotTableTotalOptionsOutputTypeDef,
    PivotTableTotalOptionsTypeDef,
    GaugeChartConditionalFormattingOptionOutputTypeDef,
    KPIConditionalFormattingOptionOutputTypeDef,
    FilledMapShapeConditionalFormattingOutputTypeDef,
    PivotTableCellConditionalFormattingOutputTypeDef,
    TableCellConditionalFormattingOutputTypeDef,
    GaugeChartConditionalFormattingOptionTypeDef,
    KPIConditionalFormattingOptionTypeDef,
    FilledMapShapeConditionalFormattingTypeDef,
    PivotTableCellConditionalFormattingTypeDef,
    TableCellConditionalFormattingTypeDef,
    DescribeAssetBundleImportJobResponseTypeDef,
    AssetBundleImportJobOverrideParametersUnionTypeDef,
    StartAssetBundleImportJobRequestRequestTypeDef,
    CreateDataSourceRequestRequestTypeDef,
    UpdateDataSourceRequestRequestTypeDef,
    ThemeTypeDef,
    GaugeChartOptionsTypeDef,
    KPIOptionsTypeDef,
    DateDimensionFieldTypeDef,
    DateMeasureFieldTypeDef,
    NumericalDimensionFieldTypeDef,
    NumericalMeasureFieldTypeDef,
    ReferenceLineLabelConfigurationTypeDef,
    CategoricalDimensionFieldTypeDef,
    CategoricalMeasureFieldTypeDef,
    FormatConfigurationTypeDef,
    FilterOutputTypeDef,
    FilterTypeDef,
    BarChartSortConfigurationOutputTypeDef,
    BarChartSortConfigurationTypeDef,
    BoxPlotSortConfigurationOutputTypeDef,
    BoxPlotSortConfigurationTypeDef,
    ComboChartSortConfigurationOutputTypeDef,
    ComboChartSortConfigurationTypeDef,
    FilledMapSortConfigurationOutputTypeDef,
    FilledMapSortConfigurationTypeDef,
    FunnelChartSortConfigurationOutputTypeDef,
    FunnelChartSortConfigurationTypeDef,
    HeatMapSortConfigurationOutputTypeDef,
    HeatMapSortConfigurationTypeDef,
    KPISortConfigurationOutputTypeDef,
    KPISortConfigurationTypeDef,
    LineChartSortConfigurationOutputTypeDef,
    LineChartSortConfigurationTypeDef,
    PieChartSortConfigurationOutputTypeDef,
    PieChartSortConfigurationTypeDef,
    RadarChartSortConfigurationOutputTypeDef,
    RadarChartSortConfigurationTypeDef,
    SankeyDiagramSortConfigurationOutputTypeDef,
    SankeyDiagramSortConfigurationTypeDef,
    TableSortConfigurationOutputTypeDef,
    TableSortConfigurationTypeDef,
    TreeMapSortConfigurationOutputTypeDef,
    TreeMapSortConfigurationTypeDef,
    WaterfallChartSortConfigurationOutputTypeDef,
    WaterfallChartSortConfigurationTypeDef,
    WordCloudSortConfigurationOutputTypeDef,
    WordCloudSortConfigurationTypeDef,
    PivotFieldSortOptionsOutputTypeDef,
    PivotFieldSortOptionsTypeDef,
    FieldBasedTooltipOutputTypeDef,
    FieldBasedTooltipTypeDef,
    TopicDetailsOutputTypeDef,
    TopicDetailsTypeDef,
    SnapshotJobResultTypeDef,
    DefaultNewSheetConfigurationTypeDef,
    BodySectionContentOutputTypeDef,
    HeaderFooterSectionConfigurationOutputTypeDef,
    BodySectionContentTypeDef,
    HeaderFooterSectionConfigurationTypeDef,
    VisualCustomActionOperationTypeDef,
    DescribeDataSetResponseTypeDef,
    CreateDataSetRequestRequestTypeDef,
    UpdateDataSetRequestRequestTypeDef,
    VisualCustomActionOutputTypeDef,
    TableFieldOptionTypeDef,
    GaugeChartConditionalFormattingOutputTypeDef,
    KPIConditionalFormattingOutputTypeDef,
    FilledMapConditionalFormattingOptionOutputTypeDef,
    PivotTableConditionalFormattingOptionOutputTypeDef,
    TableConditionalFormattingOptionOutputTypeDef,
    GaugeChartConditionalFormattingTypeDef,
    KPIConditionalFormattingTypeDef,
    FilledMapConditionalFormattingOptionTypeDef,
    PivotTableConditionalFormattingOptionTypeDef,
    TableConditionalFormattingOptionTypeDef,
    DescribeThemeResponseTypeDef,
    ReferenceLineTypeDef,
    DimensionFieldTypeDef,
    MeasureFieldTypeDef,
    ColumnConfigurationOutputTypeDef,
    ColumnConfigurationTypeDef,
    UnaggregatedFieldTypeDef,
    FilterGroupOutputTypeDef,
    FilterGroupTypeDef,
    PivotTableSortConfigurationOutputTypeDef,
    PivotTableSortConfigurationTypeDef,
    TooltipOptionsOutputTypeDef,
    TooltipOptionsTypeDef,
    DescribeTopicResponseTypeDef,
    CreateTopicRequestRequestTypeDef,
    TopicDetailsUnionTypeDef,
    UpdateTopicRequestRequestTypeDef,
    DescribeDashboardSnapshotJobResultResponseTypeDef,
    AnalysisDefaultsTypeDef,
    BodySectionConfigurationOutputTypeDef,
    BodySectionConfigurationTypeDef,
    VisualCustomActionTypeDef,
    CustomContentVisualOutputTypeDef,
    EmptyVisualOutputTypeDef,
    TableFieldOptionsOutputTypeDef,
    TableFieldOptionsTypeDef,
    FilledMapConditionalFormattingOutputTypeDef,
    PivotTableConditionalFormattingOutputTypeDef,
    TableConditionalFormattingOutputTypeDef,
    FilledMapConditionalFormattingTypeDef,
    PivotTableConditionalFormattingTypeDef,
    TableConditionalFormattingTypeDef,
    UniqueValuesComputationTypeDef,
    BarChartAggregatedFieldWellsOutputTypeDef,
    BarChartAggregatedFieldWellsTypeDef,
    BoxPlotAggregatedFieldWellsOutputTypeDef,
    BoxPlotAggregatedFieldWellsTypeDef,
    ComboChartAggregatedFieldWellsOutputTypeDef,
    ComboChartAggregatedFieldWellsTypeDef,
    FilledMapAggregatedFieldWellsOutputTypeDef,
    FilledMapAggregatedFieldWellsTypeDef,
    ForecastComputationTypeDef,
    FunnelChartAggregatedFieldWellsOutputTypeDef,
    FunnelChartAggregatedFieldWellsTypeDef,
    GaugeChartFieldWellsOutputTypeDef,
    GaugeChartFieldWellsTypeDef,
    GeospatialMapAggregatedFieldWellsOutputTypeDef,
    GeospatialMapAggregatedFieldWellsTypeDef,
    GrowthRateComputationTypeDef,
    HeatMapAggregatedFieldWellsOutputTypeDef,
    HeatMapAggregatedFieldWellsTypeDef,
    HistogramAggregatedFieldWellsOutputTypeDef,
    HistogramAggregatedFieldWellsTypeDef,
    KPIFieldWellsOutputTypeDef,
    KPIFieldWellsTypeDef,
    LineChartAggregatedFieldWellsOutputTypeDef,
    LineChartAggregatedFieldWellsTypeDef,
    MaximumMinimumComputationTypeDef,
    MetricComparisonComputationTypeDef,
    PeriodOverPeriodComputationTypeDef,
    PeriodToDateComputationTypeDef,
    PieChartAggregatedFieldWellsOutputTypeDef,
    PieChartAggregatedFieldWellsTypeDef,
    PivotTableAggregatedFieldWellsOutputTypeDef,
    PivotTableAggregatedFieldWellsTypeDef,
    RadarChartAggregatedFieldWellsOutputTypeDef,
    RadarChartAggregatedFieldWellsTypeDef,
    SankeyDiagramAggregatedFieldWellsOutputTypeDef,
    SankeyDiagramAggregatedFieldWellsTypeDef,
    ScatterPlotCategoricallyAggregatedFieldWellsOutputTypeDef,
    ScatterPlotCategoricallyAggregatedFieldWellsTypeDef,
    ScatterPlotUnaggregatedFieldWellsOutputTypeDef,
    ScatterPlotUnaggregatedFieldWellsTypeDef,
    TableAggregatedFieldWellsOutputTypeDef,
    TableAggregatedFieldWellsTypeDef,
    TopBottomMoversComputationTypeDef,
    TopBottomRankedComputationTypeDef,
    TotalAggregationComputationTypeDef,
    TreeMapAggregatedFieldWellsOutputTypeDef,
    TreeMapAggregatedFieldWellsTypeDef,
    WaterfallChartAggregatedFieldWellsOutputTypeDef,
    WaterfallChartAggregatedFieldWellsTypeDef,
    WordCloudAggregatedFieldWellsOutputTypeDef,
    WordCloudAggregatedFieldWellsTypeDef,
    TableUnaggregatedFieldWellsOutputTypeDef,
    TableUnaggregatedFieldWellsTypeDef,
    SectionBasedLayoutConfigurationOutputTypeDef,
    SectionBasedLayoutConfigurationTypeDef,
    CustomContentVisualTypeDef,
    EmptyVisualTypeDef,
    BarChartFieldWellsOutputTypeDef,
    BarChartFieldWellsTypeDef,
    BoxPlotFieldWellsOutputTypeDef,
    BoxPlotFieldWellsTypeDef,
    ComboChartFieldWellsOutputTypeDef,
    ComboChartFieldWellsTypeDef,
    FilledMapFieldWellsOutputTypeDef,
    FilledMapFieldWellsTypeDef,
    FunnelChartFieldWellsOutputTypeDef,
    FunnelChartFieldWellsTypeDef,
    GaugeChartConfigurationOutputTypeDef,
    GaugeChartConfigurationTypeDef,
    GeospatialMapFieldWellsOutputTypeDef,
    GeospatialMapFieldWellsTypeDef,
    HeatMapFieldWellsOutputTypeDef,
    HeatMapFieldWellsTypeDef,
    HistogramFieldWellsOutputTypeDef,
    HistogramFieldWellsTypeDef,
    KPIConfigurationOutputTypeDef,
    KPIConfigurationTypeDef,
    LineChartFieldWellsOutputTypeDef,
    LineChartFieldWellsTypeDef,
    PieChartFieldWellsOutputTypeDef,
    PieChartFieldWellsTypeDef,
    PivotTableFieldWellsOutputTypeDef,
    PivotTableFieldWellsTypeDef,
    RadarChartFieldWellsOutputTypeDef,
    RadarChartFieldWellsTypeDef,
    SankeyDiagramFieldWellsOutputTypeDef,
    SankeyDiagramFieldWellsTypeDef,
    ScatterPlotFieldWellsOutputTypeDef,
    ScatterPlotFieldWellsTypeDef,
    ComputationTypeDef,
    TreeMapFieldWellsOutputTypeDef,
    TreeMapFieldWellsTypeDef,
    WaterfallChartFieldWellsOutputTypeDef,
    WaterfallChartFieldWellsTypeDef,
    WordCloudFieldWellsOutputTypeDef,
    WordCloudFieldWellsTypeDef,
    TableFieldWellsOutputTypeDef,
    TableFieldWellsTypeDef,
    LayoutConfigurationOutputTypeDef,
    LayoutConfigurationTypeDef,
    BarChartConfigurationOutputTypeDef,
    BarChartConfigurationTypeDef,
    BoxPlotChartConfigurationOutputTypeDef,
    BoxPlotChartConfigurationTypeDef,
    ComboChartConfigurationOutputTypeDef,
    ComboChartConfigurationTypeDef,
    FilledMapConfigurationOutputTypeDef,
    FilledMapConfigurationTypeDef,
    FunnelChartConfigurationOutputTypeDef,
    FunnelChartConfigurationTypeDef,
    GaugeChartVisualOutputTypeDef,
    GaugeChartVisualTypeDef,
    GeospatialMapConfigurationOutputTypeDef,
    GeospatialMapConfigurationTypeDef,
    HeatMapConfigurationOutputTypeDef,
    HeatMapConfigurationTypeDef,
    HistogramConfigurationOutputTypeDef,
    HistogramConfigurationTypeDef,
    KPIVisualOutputTypeDef,
    KPIVisualTypeDef,
    LineChartConfigurationOutputTypeDef,
    LineChartConfigurationTypeDef,
    PieChartConfigurationOutputTypeDef,
    PieChartConfigurationTypeDef,
    PivotTableConfigurationOutputTypeDef,
    PivotTableConfigurationTypeDef,
    RadarChartConfigurationOutputTypeDef,
    RadarChartConfigurationTypeDef,
    SankeyDiagramChartConfigurationOutputTypeDef,
    SankeyDiagramChartConfigurationTypeDef,
    ScatterPlotConfigurationOutputTypeDef,
    ScatterPlotConfigurationTypeDef,
    InsightConfigurationOutputTypeDef,
    InsightConfigurationTypeDef,
    TreeMapConfigurationOutputTypeDef,
    TreeMapConfigurationTypeDef,
    WaterfallChartConfigurationOutputTypeDef,
    WaterfallChartConfigurationTypeDef,
    WordCloudChartConfigurationOutputTypeDef,
    WordCloudChartConfigurationTypeDef,
    TableConfigurationOutputTypeDef,
    TableConfigurationTypeDef,
    LayoutOutputTypeDef,
    LayoutTypeDef,
    BarChartVisualOutputTypeDef,
    BarChartVisualTypeDef,
    BoxPlotVisualOutputTypeDef,
    BoxPlotVisualTypeDef,
    ComboChartVisualOutputTypeDef,
    ComboChartVisualTypeDef,
    FilledMapVisualOutputTypeDef,
    FilledMapVisualTypeDef,
    FunnelChartVisualOutputTypeDef,
    FunnelChartVisualTypeDef,
    GeospatialMapVisualOutputTypeDef,
    GeospatialMapVisualTypeDef,
    HeatMapVisualOutputTypeDef,
    HeatMapVisualTypeDef,
    HistogramVisualOutputTypeDef,
    HistogramVisualTypeDef,
    LineChartVisualOutputTypeDef,
    LineChartVisualTypeDef,
    PieChartVisualOutputTypeDef,
    PieChartVisualTypeDef,
    PivotTableVisualOutputTypeDef,
    PivotTableVisualTypeDef,
    RadarChartVisualOutputTypeDef,
    RadarChartVisualTypeDef,
    SankeyDiagramVisualOutputTypeDef,
    SankeyDiagramVisualTypeDef,
    ScatterPlotVisualOutputTypeDef,
    ScatterPlotVisualTypeDef,
    InsightVisualOutputTypeDef,
    InsightVisualTypeDef,
    TreeMapVisualOutputTypeDef,
    TreeMapVisualTypeDef,
    WaterfallVisualOutputTypeDef,
    WaterfallVisualTypeDef,
    WordCloudVisualOutputTypeDef,
    WordCloudVisualTypeDef,
    TableVisualOutputTypeDef,
    TableVisualTypeDef,
    VisualOutputTypeDef,
    VisualTypeDef,
    SheetDefinitionOutputTypeDef,
    SheetDefinitionTypeDef,
    AnalysisDefinitionOutputTypeDef,
    DashboardVersionDefinitionOutputTypeDef,
    TemplateVersionDefinitionOutputTypeDef,
    AnalysisDefinitionTypeDef,
    DashboardVersionDefinitionTypeDef,
    TemplateVersionDefinitionTypeDef,
    DescribeAnalysisDefinitionResponseTypeDef,
    DescribeDashboardDefinitionResponseTypeDef,
    DescribeTemplateDefinitionResponseTypeDef,
    AnalysisDefinitionUnionTypeDef,
    CreateAnalysisRequestRequestTypeDef,
    UpdateAnalysisRequestRequestTypeDef,
    CreateDashboardRequestRequestTypeDef,
    DashboardVersionDefinitionUnionTypeDef,
    UpdateDashboardRequestRequestTypeDef,
    CreateTemplateRequestRequestTypeDef,
    TemplateVersionDefinitionUnionTypeDef,
    UpdateTemplateRequestRequestTypeDef,
)


def get_value() -> AccountCustomizationTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for `boto3`
updates. It delivers drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type
  annotations extracted from `botocore` schemas.
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore`, `aiobotocore` and `aioboto3`
  libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.resource` calls
- Auto discovery of types for `session.client` and `session.resource` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`mypy-boto3-quicksight` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[boto3 docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_quicksight/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
